@@ -64,10 +64,10 @@
 
 #include <string.h>
 #include <malloc.h>
+#include "afsd.h"
 #include <osi.h>
 #include <rx/rx.h>
 
-#include "afsd.h"
 
 static osi_once_t cm_utilsOnce;
 
@@ -261,13 +261,9 @@ long cm_MapRPCError(long error, cm_req_t *reqp)
               || error == 122   /* EDQUOT on Linux */
               || error == 1133) /* EDQUOT on Irix  */
         error = CM_ERROR_QUOTA;
-    else if (error == VNOVNODE) {
-#ifdef COMMENT
+    else if (error == VNOVNODE)
         error = CM_ERROR_BADFD;
-#else
-        error = CM_ERROR_RETRY;
-#endif
-    } else if (error == 21)
+    else if (error == 21)
         return CM_ERROR_ISDIR;
     return error;
 }
@@ -288,6 +284,8 @@ long cm_MapRPCErrorRmdir(long error, cm_req_t *reqp)
         return error;
     }
 
+    error = et_to_sys_error(error);
+
     if (error < 0) 
         error = CM_ERROR_TIMEDOUT;
     else if (error == 30) 
@@ -308,24 +306,26 @@ long cm_MapRPCErrorRmdir(long error, cm_req_t *reqp)
 
 long cm_MapVLRPCError(long error, cm_req_t *reqp)
 {
-	if (error == 0) return 0;
+    if (error == 0) return 0;
 
-	/* If we had to stop retrying, report our saved error code. */
-	if (reqp && error == CM_ERROR_TIMEDOUT) {
-		if (reqp->accessError)
-			return reqp->accessError;
-		if (reqp->volumeError)
-			return reqp->volumeError;
-		if (reqp->rpcError)
-			return reqp->rpcError;
-		return error;
-	}
-
-	if (error < 0) 
-            error = CM_ERROR_TIMEDOUT;
-	else if (error == VL_NOENT) 
-            error = CM_ERROR_NOSUCHVOLUME;
+    /* If we had to stop retrying, report our saved error code. */
+    if (reqp && error == CM_ERROR_TIMEDOUT) {
+	if (reqp->accessError)
+	    return reqp->accessError;
+	if (reqp->volumeError)
+	    return reqp->volumeError;
+	if (reqp->rpcError)
+	    return reqp->rpcError;
 	return error;
+    }
+
+    error = et_to_sys_error(error);
+
+    if (error < 0) 
+	error = CM_ERROR_TIMEDOUT;
+    else if (error == VL_NOENT) 
+	error = CM_ERROR_NOSUCHVOLUME;
+    return error;
 }
 
 cm_space_t *cm_GetSpace(void)
