@@ -58,7 +58,7 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/afsd/afsd.c,v 1.60.2.1 2006/06/15 15:53:00 shadow Exp $");
+    ("$Header: /cvs/openafs/src/afsd/afsd.c,v 1.60.2.3 2007/02/09 01:00:18 shadow Exp $");
 
 #define VFS 1
 
@@ -133,7 +133,6 @@ RCSID
 #include <netinet/in.h>
 #include <afs/afs_args.h>
 #include <afs/cellconfig.h>
-#include <afs/auth.h>
 #include <ctype.h>
 #include <afs/afssyscalls.h>
 #include <afs/afsutil.h>
@@ -1687,12 +1686,19 @@ mainproc(struct cmd_syndesc *as, char *arock)
 	    if (afsd_verbose)
 		printf("%s: cacheFiles autotuned to %d\n", rn, cacheFiles);
 	}
+#if 0
+       /* This actually needs to
+          1) use powers of 2
+          2) not second-guess when a chunksize comes from the command line
+          3) be less, um, small. 2^2?? 
+       */
 	/* Sanity check chunkSize */
 	i = max(cacheBlocks / 1000, cacheBlocks / cacheFiles);
 	chunkSize = min(chunkSize, i);
 	chunkSize = max(chunkSize, 2);
 	if (afsd_verbose)
 	    printf("%s: chunkSize autotuned to %d\n", rn, chunkSize);
+#endif
 
 	if (!sawDCacheSize) {
 	    dCacheSize = cacheFiles / 2;
